# 虚拟病人服务部署文档

## 需要部署的服务列表

1. 后端系统
2. nginx前端服务

# 注意

如果镜像拉的时候,报错:

Error response from daemon: error parsing HTTP 408 response body:
invalid character '<' looking for beginning of value:
"<html><body><h1>408 Request Time-out</h1>\n
Your browser didn't send a complete request in time.\n</body></html>\n"

这个时候,需要修改网卡地址
先ifconfig,找到对应网卡的地址,然后指定命令

ifconfig {eth0} mtu 900


## 后端系统部署

- 端口号：8891
- 首次部署使用dockerfile的形式,后期更新直接docker restart就可以了
- 将代码包virtual-patient-manage-1.0-SNAPSHOT.jar拷贝到路径/data/vp下

### 首次部署

~~~shell
    # 进入/data/kbqa/kbqa-graph文件夹，依次执行命令
    # 构建镜像
    docker build -t kbqa-graph:1.0.0 .
    # 验证镜像是否存在
    docker images | grep kbqa-graph
    # 运行容器
    docker run --name kbqa-graph -p 9811:9811 -v /data/kbqa:/data/kbqa -d kbqa-graph:1.0.0
    # 验证容器运行
    docker ps | grep kbqa-graph
    # 查看日志是否正常
    docker logs -f kbqa-graph
~~~

### 服务更新

- 将代码包kbqa-graph-1.0-SNAPSHOT.jar拷贝到路径/data/kbqa
- 重启容器

~~~shell
    docker restart kbqa-graph
~~~


## Nginx前端服务

~~~shell
    # 进入nginx文件夹，依次执行命令
    # 修改 conf.d文件目录下servers.conf.template文件中的$UPSTREAM_WEB_SERVERS，$UPSTREAM_MANAGE_SERVERS
    # 构建镜像 1.1.0
    docker build -t virtual-patient-nginx:1.1.0 .
    # 验证镜像是否存在
    docker images | grep virtual-patient-nginx
    # 运行容器 **如果某一个服务没有部署可以不填该服务的地址**
    docker run --name virtual-patient-nginx -p 443:443 -v /data/vp/dist:/usr/share/nginx/html/dist -d -e UPSTREAM_WEB_SERVERS={ip}:{port} -e UPSTREAM_MANAGE_SERVERS={ip}:{port} -e UPSTREAM_RASA_SERVERS={ip}:{port}  -e UPSTREAM_GRAPH_SERVERS={ip}:{port} virtual-patient-nginx:1.1.0
    # UPSTREAM_WEB_SERVERS:虚拟病人问诊系统服务的ip:port
    # UPSTREAM_MANAGE_SERVERS:虚拟病人后端管理系统服务的ip:port
    
    # **启用网络环境服务，生产环境请使用 不放80,只放https的443** **如果某一个服务没有部署可以不填该服务的地址**
    docker run --name virtual-patient-nginx  -p 443:443 --network virtual-patient-network -v /data/vp/dist:/usr/share/nginx/html/dist -d -e UPSTREAM_WEB_SERVERS=virtual-patient-web:8899 -e UPSTREAM_MANAGE_SERVERS=virtual-patient-manage:8891 -e UPSTREAM_RASA_SERVERS=virtual-patient-rasa-manage:8990  -e UPSTREAM_GRAPH_SERVERS=virtual-patient-graph:8992 virtual-patient-nginx:1.1.0
    # 验证容器运行
    docker ps
    # 查看日志是否正常
    docker logs -f virtual-patient-nginx
~~~

### 服务更新
- 重新构建nginx镜像
    - docker build -t virtual-patient-nginx:1.1.0 .
- 将前端代码包dist文件夹拷贝到路径/data/vp/下
- 重启容器

~~~shell
    docker restart virtual-patient-nginx
~~~